@@ -23,7 +23,7 @@ use W3C::SOAP::Utils qw/split_ns/;
 use TryCatch;
 use DateTime::Format::Strptime qw/strptime/;
 
-our $VERSION     = version->new('0.0.4');
+our $VERSION     = version->new('0.0.5');
 
 has xsd_ns => (
     is  => 'rw',
@@ -43,6 +43,7 @@ has xsd_ns_name => (
     my $require = sub {
         my ($module) = @_;
         return if $required{$module}++;
+        return if UNIVERSAL::can($module, 'new');
 
         my $file = "$module.pm";
         $file =~ s{::}{/}g;
@@ -178,14 +179,14 @@ sub to_xml {
                 my @children = $item->to_xml($xml);
                 $tag->appendChild($_) for @children;
             }
-            elsif ( ! defined $item && ! $att->has_xs_searalize ) {
+            elsif ( ! defined $item && ! $att->has_xs_serialize ) {
                 $tag->setAttribute('nil', 'true');
             }
             else {
                 local $_ = $item;
                 my $text
-                    = $att->has_xs_searalize
-                    ? $att->xs_searalize->($item)
+                    = $att->has_xs_serialize
+                    ? $att->xs_serialize->($item)
                     : "$item";
                 $tag->appendChild( $xml->createTextNode($text) );
             }
@@ -231,13 +232,13 @@ sub to_data {
             if ( blessed($value) && $value->can('to_data') ) {
                 $value = $value->to_data(%option);
             }
-            elsif ( ! defined $value && ! $att->has_xs_searalize ) {
+            elsif ( ! defined $value && ! $att->has_xs_serialize ) {
             }
             elsif ($option{stringify}) {
                 local $_ = $value;
                 my $text
-                    = $att->has_xs_searalize
-                    ? $att->xs_searalize->($value)
+                    = $att->has_xs_serialize
+                    ? $att->xs_serialize->($value)
                     : "$value";
                 $value = defined $value ? $text : $value;
             }
@@ -329,6 +330,14 @@ sub xsd_subtype {
             via { $_->textContent };
     }
 
+    # Propogate coercion from Any via parent's type coercion.
+    my $this_type = $subtype->parent;
+    if ($this_type->has_parent) {
+        coerce $subtype
+            => from 'Any'
+            => via { $this_type->parent->coerce($_) };
+    }
+
     return $subtype;
 }
 
@@ -342,7 +351,7 @@ W3C::SOAP::XSD - The parent module to XSD modules
 
 =head1 VERSION
 
-This documentation refers to W3C::SOAP::XSD version 0.0.4.
+This documentation refers to W3C::SOAP::XSD version 0.0.5.
 
 =head1 SYNOPSIS
 
